@@ -1,5 +1,5 @@
 /*
-Copyright © 2024 Mahmoud Mosua <m.mousa@hey.com>
+Copyright © 2024 Mahmoud Mousa <m.mousa@hey.com>
 
 Licensed under the GNU GPL License, Version 3.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -17,18 +17,21 @@ package cmd
 import (
 	"os"
 
+	"github.com/mightymoud/sidekick/cmd/deploy"
+	"github.com/mightymoud/sidekick/cmd/launch"
+	"github.com/mightymoud/sidekick/cmd/preview"
 	"github.com/spf13/cobra"
 )
 
-// rootCmd represents the base command when called without any subcommands
+var version = "dev"
+
 var rootCmd = &cobra.Command{
-	Use:   "sidekick",
-	Short: "CLI to self-host all your apps on a sinlge VPS without vendor locking",
-	Long:  `With sidekick you can deploy any number of applications to a single VPS, connect multiple domains and much more.`,
+	Use:     "sidekick",
+	Version: version,
+	Short:   "CLI to self-host all your apps on a single VPS without vendor locking",
+	Long:    `With sidekick you can deploy any number of applications to a single VPS, connect multiple domains and much more.`,
 }
 
-// Execute adds all child commands to the root command and sets flags appropriately.
-// This is called by main.main(). It only needs to happen once to the rootCmd.
 func Execute() {
 	err := rootCmd.Execute()
 	if err != nil {
@@ -37,5 +40,8 @@ func Execute() {
 }
 
 func init() {
-	rootCmd.Flags().BoolP("toggle", "t", false, "Help message for toggle")
+	rootCmd.SetVersionTemplate(`{{println .Version}}`)
+	rootCmd.AddCommand(preview.PreviewCmd)
+	rootCmd.AddCommand(deploy.DeployCmd)
+	rootCmd.AddCommand(launch.LaunchCmd)
 }
